#![no_std]
#![warn(missing_docs)]
#![allow(clippy::many_single_char_names)]

//! A crate for hekkin vectors.
//!
//! This crate is fairly well tested where functionality does exist, but is
//! mostly incomplete at the moment.
//!
//! ## Features
//!
//! * `free_functions` adds the [`free_functions`] module (on by default).
//! * `serde` adds [serde](http://docs.rs/serde) 1.0 support (off by default).
//! * `mint` adds [mint](http://docs.rs/mint) 0.5 support (off by default).

use core::{convert::*, ops::*};
#[cfg(target_arch = "x86")]
use lokacore::arch::x86::*;
#[cfg(target_arch = "x86_64")]
use lokacore::arch::x86_64::*;
use lokacore::*;

macro_rules! if_sse {
  ($sse_yes:block else $sse_no:block) => {{
    #[cfg(target_feature="sse")]
    $sse_yes
    #[cfg(not(target_feature="sse"))]
    $sse_no
  }}
}

mod vec2;
pub use vec2::*;

mod vec3;
pub use vec3::*;

mod vec4;
pub use vec4::*;

mod swizzle2;
mod swizzle3;
mod swizzle4;

mod mat2;
pub use mat2::*;

mod mat3;
pub use mat3::*;

mod mat4;
pub use mat4::*;

mod quat;
pub use quat::*;

pub mod free_functions;
#[cfg(feature = "free_functions")]
pub use free_functions::*;
