// swizzle characters: ['x', 'y', 'z', 'w']
use super::*;
impl Vec4 {
  /// Swizzle: obtains the `ww` combination
  pub fn ww(self) -> Vec2 {
    let temp = self.wwww();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `www` combination
  pub fn www(self) -> Vec3 {
    Vec3 { v4: self.wwwx() }
  }
  /// Swizzle: obtains the `wwww` combination
  pub fn wwww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwwx` combination
  pub fn wwwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwwy` combination
  pub fn wwwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwwz` combination
  pub fn wwwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwx` combination
  pub fn wwx(self) -> Vec3 {
    Vec3 { v4: self.wwxx() }
  }
  /// Swizzle: obtains the `wwxw` combination
  pub fn wwxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwxx` combination
  pub fn wwxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwxy` combination
  pub fn wwxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwxz` combination
  pub fn wwxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwy` combination
  pub fn wwy(self) -> Vec3 {
    Vec3 { v4: self.wwyx() }
  }
  /// Swizzle: obtains the `wwyw` combination
  pub fn wwyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwyx` combination
  pub fn wwyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwyy` combination
  pub fn wwyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwyz` combination
  pub fn wwyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwz` combination
  pub fn wwz(self) -> Vec3 {
    Vec3 { v4: self.wwzx() }
  }
  /// Swizzle: obtains the `wwzw` combination
  pub fn wwzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwzx` combination
  pub fn wwzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwzy` combination
  pub fn wwzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wwzz` combination
  pub fn wwzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 3, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[3],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wx` combination
  pub fn wx(self) -> Vec2 {
    let temp = self.wxwx();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `wxw` combination
  pub fn wxw(self) -> Vec3 {
    Vec3 { v4: self.wxwx() }
  }
  /// Swizzle: obtains the `wxww` combination
  pub fn wxww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxwx` combination
  pub fn wxwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxwy` combination
  pub fn wxwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxwz` combination
  pub fn wxwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxx` combination
  pub fn wxx(self) -> Vec3 {
    Vec3 { v4: self.wxxx() }
  }
  /// Swizzle: obtains the `wxxw` combination
  pub fn wxxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxxx` combination
  pub fn wxxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxxy` combination
  pub fn wxxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxxz` combination
  pub fn wxxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxy` combination
  pub fn wxy(self) -> Vec3 {
    Vec3 { v4: self.wxyx() }
  }
  /// Swizzle: obtains the `wxyw` combination
  pub fn wxyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxyx` combination
  pub fn wxyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxyy` combination
  pub fn wxyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxyz` combination
  pub fn wxyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxz` combination
  pub fn wxz(self) -> Vec3 {
    Vec3 { v4: self.wxzx() }
  }
  /// Swizzle: obtains the `wxzw` combination
  pub fn wxzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxzx` combination
  pub fn wxzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxzy` combination
  pub fn wxzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wxzz` combination
  pub fn wxzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 0, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[0],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wy` combination
  pub fn wy(self) -> Vec2 {
    let temp = self.wywy();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `wyw` combination
  pub fn wyw(self) -> Vec3 {
    Vec3 { v4: self.wywx() }
  }
  /// Swizzle: obtains the `wyww` combination
  pub fn wyww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wywx` combination
  pub fn wywx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wywy` combination
  pub fn wywy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wywz` combination
  pub fn wywz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyx` combination
  pub fn wyx(self) -> Vec3 {
    Vec3 { v4: self.wyxx() }
  }
  /// Swizzle: obtains the `wyxw` combination
  pub fn wyxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyxx` combination
  pub fn wyxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyxy` combination
  pub fn wyxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyxz` combination
  pub fn wyxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyy` combination
  pub fn wyy(self) -> Vec3 {
    Vec3 { v4: self.wyyx() }
  }
  /// Swizzle: obtains the `wyyw` combination
  pub fn wyyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyyx` combination
  pub fn wyyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyyy` combination
  pub fn wyyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyyz` combination
  pub fn wyyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyz` combination
  pub fn wyz(self) -> Vec3 {
    Vec3 { v4: self.wyzx() }
  }
  /// Swizzle: obtains the `wyzw` combination
  pub fn wyzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyzx` combination
  pub fn wyzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyzy` combination
  pub fn wyzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wyzz` combination
  pub fn wyzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 1, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[1],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wz` combination
  pub fn wz(self) -> Vec2 {
    let temp = self.wzwz();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `wzw` combination
  pub fn wzw(self) -> Vec3 {
    Vec3 { v4: self.wzwx() }
  }
  /// Swizzle: obtains the `wzww` combination
  pub fn wzww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzwx` combination
  pub fn wzwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzwy` combination
  pub fn wzwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzwz` combination
  pub fn wzwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzx` combination
  pub fn wzx(self) -> Vec3 {
    Vec3 { v4: self.wzxx() }
  }
  /// Swizzle: obtains the `wzxw` combination
  pub fn wzxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzxx` combination
  pub fn wzxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzxy` combination
  pub fn wzxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzxz` combination
  pub fn wzxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzy` combination
  pub fn wzy(self) -> Vec3 {
    Vec3 { v4: self.wzyx() }
  }
  /// Swizzle: obtains the `wzyw` combination
  pub fn wzyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzyx` combination
  pub fn wzyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzyy` combination
  pub fn wzyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzyz` combination
  pub fn wzyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzz` combination
  pub fn wzz(self) -> Vec3 {
    Vec3 { v4: self.wzzx() }
  }
  /// Swizzle: obtains the `wzzw` combination
  pub fn wzzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzzx` combination
  pub fn wzzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzzy` combination
  pub fn wzzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `wzzz` combination
  pub fn wzzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [3, 2, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[3],
        self.arr[2],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xw` combination
  pub fn xw(self) -> Vec2 {
    let temp = self.xwxw();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `xww` combination
  pub fn xww(self) -> Vec3 {
    Vec3 { v4: self.xwwx() }
  }
  /// Swizzle: obtains the `xwww` combination
  pub fn xwww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwwx` combination
  pub fn xwwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwwy` combination
  pub fn xwwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwwz` combination
  pub fn xwwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwx` combination
  pub fn xwx(self) -> Vec3 {
    Vec3 { v4: self.xwxx() }
  }
  /// Swizzle: obtains the `xwxw` combination
  pub fn xwxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwxx` combination
  pub fn xwxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwxy` combination
  pub fn xwxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwxz` combination
  pub fn xwxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwy` combination
  pub fn xwy(self) -> Vec3 {
    Vec3 { v4: self.xwyx() }
  }
  /// Swizzle: obtains the `xwyw` combination
  pub fn xwyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwyx` combination
  pub fn xwyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwyy` combination
  pub fn xwyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwyz` combination
  pub fn xwyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwz` combination
  pub fn xwz(self) -> Vec3 {
    Vec3 { v4: self.xwzx() }
  }
  /// Swizzle: obtains the `xwzw` combination
  pub fn xwzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwzx` combination
  pub fn xwzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwzy` combination
  pub fn xwzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xwzz` combination
  pub fn xwzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 3, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[3],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xx` combination
  pub fn xx(self) -> Vec2 {
    let temp = self.xxxx();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `xxw` combination
  pub fn xxw(self) -> Vec3 {
    Vec3 { v4: self.xxwx() }
  }
  /// Swizzle: obtains the `xxww` combination
  pub fn xxww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxwx` combination
  pub fn xxwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxwy` combination
  pub fn xxwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxwz` combination
  pub fn xxwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxx` combination
  pub fn xxx(self) -> Vec3 {
    Vec3 { v4: self.xxxx() }
  }
  /// Swizzle: obtains the `xxxw` combination
  pub fn xxxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxxx` combination
  pub fn xxxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxxy` combination
  pub fn xxxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxxz` combination
  pub fn xxxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxy` combination
  pub fn xxy(self) -> Vec3 {
    Vec3 { v4: self.xxyx() }
  }
  /// Swizzle: obtains the `xxyw` combination
  pub fn xxyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxyx` combination
  pub fn xxyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxyy` combination
  pub fn xxyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxyz` combination
  pub fn xxyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxz` combination
  pub fn xxz(self) -> Vec3 {
    Vec3 { v4: self.xxzx() }
  }
  /// Swizzle: obtains the `xxzw` combination
  pub fn xxzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxzx` combination
  pub fn xxzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxzy` combination
  pub fn xxzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xxzz` combination
  pub fn xxzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 0, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[0],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xy` combination
  pub fn xy(self) -> Vec2 {
    let temp = self.xyxy();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `xyw` combination
  pub fn xyw(self) -> Vec3 {
    Vec3 { v4: self.xywx() }
  }
  /// Swizzle: obtains the `xyww` combination
  pub fn xyww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xywx` combination
  pub fn xywx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xywy` combination
  pub fn xywy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xywz` combination
  pub fn xywz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyx` combination
  pub fn xyx(self) -> Vec3 {
    Vec3 { v4: self.xyxx() }
  }
  /// Swizzle: obtains the `xyxw` combination
  pub fn xyxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyxx` combination
  pub fn xyxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyxy` combination
  pub fn xyxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyxz` combination
  pub fn xyxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyy` combination
  pub fn xyy(self) -> Vec3 {
    Vec3 { v4: self.xyyx() }
  }
  /// Swizzle: obtains the `xyyw` combination
  pub fn xyyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyyx` combination
  pub fn xyyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyyy` combination
  pub fn xyyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyyz` combination
  pub fn xyyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyz` combination
  pub fn xyz(self) -> Vec3 {
    Vec3 { v4: self.xyzx() }
  }
  /// Swizzle: obtains the `xyzw` combination
  pub fn xyzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyzx` combination
  pub fn xyzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyzy` combination
  pub fn xyzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xyzz` combination
  pub fn xyzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 1, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[1],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xz` combination
  pub fn xz(self) -> Vec2 {
    let temp = self.xzxz();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `xzw` combination
  pub fn xzw(self) -> Vec3 {
    Vec3 { v4: self.xzwx() }
  }
  /// Swizzle: obtains the `xzww` combination
  pub fn xzww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzwx` combination
  pub fn xzwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzwy` combination
  pub fn xzwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzwz` combination
  pub fn xzwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzx` combination
  pub fn xzx(self) -> Vec3 {
    Vec3 { v4: self.xzxx() }
  }
  /// Swizzle: obtains the `xzxw` combination
  pub fn xzxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzxx` combination
  pub fn xzxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzxy` combination
  pub fn xzxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzxz` combination
  pub fn xzxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzy` combination
  pub fn xzy(self) -> Vec3 {
    Vec3 { v4: self.xzyx() }
  }
  /// Swizzle: obtains the `xzyw` combination
  pub fn xzyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzyx` combination
  pub fn xzyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzyy` combination
  pub fn xzyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzyz` combination
  pub fn xzyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzz` combination
  pub fn xzz(self) -> Vec3 {
    Vec3 { v4: self.xzzx() }
  }
  /// Swizzle: obtains the `xzzw` combination
  pub fn xzzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzzx` combination
  pub fn xzzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzzy` combination
  pub fn xzzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `xzzz` combination
  pub fn xzzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [0, 2, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[0],
        self.arr[2],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yw` combination
  pub fn yw(self) -> Vec2 {
    let temp = self.ywyw();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `yww` combination
  pub fn yww(self) -> Vec3 {
    Vec3 { v4: self.ywwx() }
  }
  /// Swizzle: obtains the `ywww` combination
  pub fn ywww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywwx` combination
  pub fn ywwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywwy` combination
  pub fn ywwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywwz` combination
  pub fn ywwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywx` combination
  pub fn ywx(self) -> Vec3 {
    Vec3 { v4: self.ywxx() }
  }
  /// Swizzle: obtains the `ywxw` combination
  pub fn ywxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywxx` combination
  pub fn ywxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywxy` combination
  pub fn ywxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywxz` combination
  pub fn ywxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywy` combination
  pub fn ywy(self) -> Vec3 {
    Vec3 { v4: self.ywyx() }
  }
  /// Swizzle: obtains the `ywyw` combination
  pub fn ywyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywyx` combination
  pub fn ywyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywyy` combination
  pub fn ywyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywyz` combination
  pub fn ywyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywz` combination
  pub fn ywz(self) -> Vec3 {
    Vec3 { v4: self.ywzx() }
  }
  /// Swizzle: obtains the `ywzw` combination
  pub fn ywzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywzx` combination
  pub fn ywzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywzy` combination
  pub fn ywzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `ywzz` combination
  pub fn ywzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 3, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[3],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yx` combination
  pub fn yx(self) -> Vec2 {
    let temp = self.yxyx();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `yxw` combination
  pub fn yxw(self) -> Vec3 {
    Vec3 { v4: self.yxwx() }
  }
  /// Swizzle: obtains the `yxww` combination
  pub fn yxww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxwx` combination
  pub fn yxwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxwy` combination
  pub fn yxwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxwz` combination
  pub fn yxwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxx` combination
  pub fn yxx(self) -> Vec3 {
    Vec3 { v4: self.yxxx() }
  }
  /// Swizzle: obtains the `yxxw` combination
  pub fn yxxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxxx` combination
  pub fn yxxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxxy` combination
  pub fn yxxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxxz` combination
  pub fn yxxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxy` combination
  pub fn yxy(self) -> Vec3 {
    Vec3 { v4: self.yxyx() }
  }
  /// Swizzle: obtains the `yxyw` combination
  pub fn yxyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxyx` combination
  pub fn yxyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxyy` combination
  pub fn yxyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxyz` combination
  pub fn yxyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxz` combination
  pub fn yxz(self) -> Vec3 {
    Vec3 { v4: self.yxzx() }
  }
  /// Swizzle: obtains the `yxzw` combination
  pub fn yxzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxzx` combination
  pub fn yxzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxzy` combination
  pub fn yxzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yxzz` combination
  pub fn yxzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 0, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[0],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yy` combination
  pub fn yy(self) -> Vec2 {
    let temp = self.yyyy();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `yyw` combination
  pub fn yyw(self) -> Vec3 {
    Vec3 { v4: self.yywx() }
  }
  /// Swizzle: obtains the `yyww` combination
  pub fn yyww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yywx` combination
  pub fn yywx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yywy` combination
  pub fn yywy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yywz` combination
  pub fn yywz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyx` combination
  pub fn yyx(self) -> Vec3 {
    Vec3 { v4: self.yyxx() }
  }
  /// Swizzle: obtains the `yyxw` combination
  pub fn yyxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyxx` combination
  pub fn yyxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyxy` combination
  pub fn yyxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyxz` combination
  pub fn yyxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyy` combination
  pub fn yyy(self) -> Vec3 {
    Vec3 { v4: self.yyyx() }
  }
  /// Swizzle: obtains the `yyyw` combination
  pub fn yyyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyyx` combination
  pub fn yyyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyyy` combination
  pub fn yyyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyyz` combination
  pub fn yyyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyz` combination
  pub fn yyz(self) -> Vec3 {
    Vec3 { v4: self.yyzx() }
  }
  /// Swizzle: obtains the `yyzw` combination
  pub fn yyzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyzx` combination
  pub fn yyzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyzy` combination
  pub fn yyzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yyzz` combination
  pub fn yyzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 1, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[1],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yz` combination
  pub fn yz(self) -> Vec2 {
    let temp = self.yzyz();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `yzw` combination
  pub fn yzw(self) -> Vec3 {
    Vec3 { v4: self.yzwx() }
  }
  /// Swizzle: obtains the `yzww` combination
  pub fn yzww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzwx` combination
  pub fn yzwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzwy` combination
  pub fn yzwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzwz` combination
  pub fn yzwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzx` combination
  pub fn yzx(self) -> Vec3 {
    Vec3 { v4: self.yzxx() }
  }
  /// Swizzle: obtains the `yzxw` combination
  pub fn yzxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzxx` combination
  pub fn yzxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzxy` combination
  pub fn yzxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzxz` combination
  pub fn yzxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzy` combination
  pub fn yzy(self) -> Vec3 {
    Vec3 { v4: self.yzyx() }
  }
  /// Swizzle: obtains the `yzyw` combination
  pub fn yzyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzyx` combination
  pub fn yzyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzyy` combination
  pub fn yzyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzyz` combination
  pub fn yzyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzz` combination
  pub fn yzz(self) -> Vec3 {
    Vec3 { v4: self.yzzx() }
  }
  /// Swizzle: obtains the `yzzw` combination
  pub fn yzzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzzx` combination
  pub fn yzzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzzy` combination
  pub fn yzzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `yzzz` combination
  pub fn yzzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [1, 2, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[1],
        self.arr[2],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zw` combination
  pub fn zw(self) -> Vec2 {
    let temp = self.zwzw();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `zww` combination
  pub fn zww(self) -> Vec3 {
    Vec3 { v4: self.zwwx() }
  }
  /// Swizzle: obtains the `zwww` combination
  pub fn zwww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwwx` combination
  pub fn zwwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwwy` combination
  pub fn zwwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwwz` combination
  pub fn zwwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwx` combination
  pub fn zwx(self) -> Vec3 {
    Vec3 { v4: self.zwxx() }
  }
  /// Swizzle: obtains the `zwxw` combination
  pub fn zwxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwxx` combination
  pub fn zwxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwxy` combination
  pub fn zwxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwxz` combination
  pub fn zwxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwy` combination
  pub fn zwy(self) -> Vec3 {
    Vec3 { v4: self.zwyx() }
  }
  /// Swizzle: obtains the `zwyw` combination
  pub fn zwyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwyx` combination
  pub fn zwyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwyy` combination
  pub fn zwyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwyz` combination
  pub fn zwyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwz` combination
  pub fn zwz(self) -> Vec3 {
    Vec3 { v4: self.zwzx() }
  }
  /// Swizzle: obtains the `zwzw` combination
  pub fn zwzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwzx` combination
  pub fn zwzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwzy` combination
  pub fn zwzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zwzz` combination
  pub fn zwzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 3, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[3],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zx` combination
  pub fn zx(self) -> Vec2 {
    let temp = self.zxzx();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `zxw` combination
  pub fn zxw(self) -> Vec3 {
    Vec3 { v4: self.zxwx() }
  }
  /// Swizzle: obtains the `zxww` combination
  pub fn zxww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxwx` combination
  pub fn zxwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxwy` combination
  pub fn zxwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxwz` combination
  pub fn zxwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxx` combination
  pub fn zxx(self) -> Vec3 {
    Vec3 { v4: self.zxxx() }
  }
  /// Swizzle: obtains the `zxxw` combination
  pub fn zxxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxxx` combination
  pub fn zxxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxxy` combination
  pub fn zxxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxxz` combination
  pub fn zxxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxy` combination
  pub fn zxy(self) -> Vec3 {
    Vec3 { v4: self.zxyx() }
  }
  /// Swizzle: obtains the `zxyw` combination
  pub fn zxyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxyx` combination
  pub fn zxyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxyy` combination
  pub fn zxyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxyz` combination
  pub fn zxyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxz` combination
  pub fn zxz(self) -> Vec3 {
    Vec3 { v4: self.zxzx() }
  }
  /// Swizzle: obtains the `zxzw` combination
  pub fn zxzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxzx` combination
  pub fn zxzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxzy` combination
  pub fn zxzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zxzz` combination
  pub fn zxzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 0, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[0],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zy` combination
  pub fn zy(self) -> Vec2 {
    let temp = self.zyzy();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `zyw` combination
  pub fn zyw(self) -> Vec3 {
    Vec3 { v4: self.zywx() }
  }
  /// Swizzle: obtains the `zyww` combination
  pub fn zyww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zywx` combination
  pub fn zywx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zywy` combination
  pub fn zywy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zywz` combination
  pub fn zywz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyx` combination
  pub fn zyx(self) -> Vec3 {
    Vec3 { v4: self.zyxx() }
  }
  /// Swizzle: obtains the `zyxw` combination
  pub fn zyxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyxx` combination
  pub fn zyxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyxy` combination
  pub fn zyxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyxz` combination
  pub fn zyxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyy` combination
  pub fn zyy(self) -> Vec3 {
    Vec3 { v4: self.zyyx() }
  }
  /// Swizzle: obtains the `zyyw` combination
  pub fn zyyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyyx` combination
  pub fn zyyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyyy` combination
  pub fn zyyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyyz` combination
  pub fn zyyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyz` combination
  pub fn zyz(self) -> Vec3 {
    Vec3 { v4: self.zyzx() }
  }
  /// Swizzle: obtains the `zyzw` combination
  pub fn zyzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyzx` combination
  pub fn zyzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyzy` combination
  pub fn zyzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zyzz` combination
  pub fn zyzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 1, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[1],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zz` combination
  pub fn zz(self) -> Vec2 {
    let temp = self.zzzz();
    Vec2::new(temp.x(), temp.y())
  }
  /// Swizzle: obtains the `zzw` combination
  pub fn zzw(self) -> Vec3 {
    Vec3 { v4: self.zzwx() }
  }
  /// Swizzle: obtains the `zzww` combination
  pub fn zzww(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 3, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[3],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzwx` combination
  pub fn zzwx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 3, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[3],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzwy` combination
  pub fn zzwy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 3, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[3],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzwz` combination
  pub fn zzwz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 3, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[3],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzx` combination
  pub fn zzx(self) -> Vec3 {
    Vec3 { v4: self.zzxx() }
  }
  /// Swizzle: obtains the `zzxw` combination
  pub fn zzxw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 0, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[0],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzxx` combination
  pub fn zzxx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 0, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[0],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzxy` combination
  pub fn zzxy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 0, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[0],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzxz` combination
  pub fn zzxz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 0, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[0],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzy` combination
  pub fn zzy(self) -> Vec3 {
    Vec3 { v4: self.zzyx() }
  }
  /// Swizzle: obtains the `zzyw` combination
  pub fn zzyw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 1, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[1],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzyx` combination
  pub fn zzyx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 1, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[1],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzyy` combination
  pub fn zzyy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 1, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[1],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzyz` combination
  pub fn zzyz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 1, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[1],
        self.arr[2],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzz` combination
  pub fn zzz(self) -> Vec3 {
    Vec3 { v4: self.zzzx() }
  }
  /// Swizzle: obtains the `zzzw` combination
  pub fn zzzw(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 2, 3])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[2],
        self.arr[3],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzzx` combination
  pub fn zzzx(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 2, 0])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[2],
        self.arr[0],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzzy` combination
  pub fn zzzy(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 2, 1])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[2],
        self.arr[1],
      ]}
    }}
  }
  /// Swizzle: obtains the `zzzz` combination
  pub fn zzzz(self) -> Self {
    if_sse! {{
      Self { sse:
        shuffle128!(self.sse, self.sse, [2, 2, 2, 2])
      }
    } else {
      Self { arr: [
        self.arr[2],
        self.arr[2],
        self.arr[2],
        self.arr[2],
      ]}
    }}
  }
}
